@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2010 Aaron Bentley
+# Copyright (C) 2009-2011 Aaron Bentley
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -92,28 +92,34 @@ class SwitchWithConflicts(errors.BzrCommandError):
     _fmt = 'Cannot switch while conflicts are present.'
 
 
+def is_light_checkout(tree):
+    return (tree.branch.bzrdir.root_transport.base !=
+            tree.bzrdir.root_transport.base)
+
+
 class PipeStorage(object):
     """Store and retrieve pipe data."""
 
     def __init__(self, branch):
         self.branch = branch
 
+    def get_sibling(self, prev):
+        option = 'prev_pipe' if prev else 'next_pipe'
+        sibling = self.branch.get_config().get_user_option(option)
+        if sibling == '':
+            sibling = None
+        return sibling
+
     def get_next(self):
         """Return the location of the next pipe."""
-        next = self.branch.get_config().get_user_option('next_pipe')
-        if next == '':
-            next = None
-        return next
+        return self.get_sibling(False)
 
     def get_prev(self):
         """Return the location of the previous pipe."""
-        prev = self.branch.get_config().get_user_option('prev_pipe')
-        if prev == '':
-            prev = None
-        return prev
+        return self.get_sibling(True)
 
-    def _sibling_pipe(self, url):
-        """Return a sibling pipe for a URL."""
+    def get_sibling_pipe(self, prev):
+        url = self.get_sibling(prev)
         if url is None:
             return None
         transports = [self.branch.bzrdir.root_transport]
@@ -122,11 +128,11 @@ class PipeStorage(object):
 
     def get_next_pipe(self):
         """Return the next pipe."""
-        return self._sibling_pipe(self.get_next())
+        return self.get_sibling_pipe(False)
 
     def get_prev_pipe(self):
         """Return the previous pipe."""
-        return self._sibling_pipe(self.get_prev())
+        return self.get_sibling_pipe(True)
 
     def _pipe_url(self, url):
         """Determine the url to use for a pipe.
@@ -239,10 +245,7 @@ class PipeStorage(object):
         """
         storage = self
         while True:
-            if prev:
-                next_branch = storage.get_prev_pipe()
-            else:
-                next_branch = storage.get_next_pipe()
+            next_branch = storage.get_sibling_pipe(prev)
             if next_branch is None:
                 return
             yield next_branch
@@ -363,6 +366,12 @@ class PipeManager(object):
     def get_last_pipe(self):
         return self._get_terminal_pipe(False)
 
+    def get_nearest_pipe(self):
+        nearest = self.get_next_pipe()
+        if nearest is None:
+            nearest = self.get_prev_pipe()
+        return nearest
+
     def list_pipes(self):
         return self.storage.list_pipes()
 
@@ -381,6 +390,28 @@ class PipeManager(object):
             PipeStorage.connect(self.storage.branch, next_pipe)
         switch._set_branch_location(self.checkout.bzrdir, self.storage.branch)
 
+    def is_self_checkout(self):
+        if self.checkout is None:
+            return False
+        if not is_light_checkout(self.checkout):
+            return False
+        return self.checkout.branch.base == self.storage.branch.base
+
+    def remove_pipe(self, target_branch, delete_branch):
+        """Remove this manager's pipe from the pipeline.
+
+        If the checkout is a lightweight checkout of the pipe to remove,
+        switch the checkout to target_branch first.
+
+        If delete_branch is False, the branch is removed from the pipeline but
+        remains on disk.  If True, the branch is deleted.
+        """
+        if self.is_self_checkout():
+            self.switch_to_pipe(target_branch)
+        self.storage.disconnect()
+        if delete_branch:
+            self.storage.branch.bzrdir.root_transport.delete_tree('.')
+
     def sync_pipeline(self, location, remote_branch=None):
         """Synchronize this pipeline with another, mirror-style.
 
@@ -405,7 +436,7 @@ class PipeManager(object):
             trace.note('Creating new pipe at %s', location)
             t = get_transport(location,
                               possible_transports=possible_transports)
-            local = self.storage.branch
+            local = dict(local_pipes)[remote_nick]
             revision_id = local.last_revision()
             b = local.bzrdir.clone_on_transport(t, revision_id).open_branch()
             nick = b.nick
@@ -877,20 +908,20 @@ def dwim_pipe(manager, pipe):
 def tree_to_pipeline(tree):
     """Convert a colocated tree and branch for use with pipelines.
 
-    This moves the branch of a tree into a new "pipes" subdirectory.
-    It ensures that a shared repository is in use, creating one in "pipes",
+    This moves the branch of a tree into a new "branches" subdirectory.
+    It ensures that a shared repository is in use, creating one in "branches",
     if necessary.  The previous location of the branch becomes a
     BranchReference to the new location.
     """
     if (tree.bzrdir.root_transport.base !=
         tree.branch.bzrdir.root_transport.base):
         raise errors.AlreadyLightweightCheckout(tree.bzrdir)
-    pipes_transport = tree.bzrdir.root_transport.clone('.bzr/pipes')
-    pipe_transport = pipes_transport.clone(tree.branch.nick)
+    branches_transport = tree.bzrdir.root_transport.clone('.bzr/branches')
+    pipe_transport = branches_transport.clone(tree.branch.nick)
     pipe_transport.create_prefix()
     if not tree.branch.repository.is_shared():
         format = tree.bzrdir.cloning_metadir()
-        newdir = format.initialize_on_transport(pipes_transport)
+        newdir = format.initialize_on_transport(branches_transport)
         newdir.create_repository(shared=True)
     new_branch = tree.bzrdir.sprout(pipe_transport.base,
                        possible_transports=[pipe_transport],
