@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Aaron Bentley
+# Copyright (C) 2009-2011 Aaron Bentley
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -128,13 +128,13 @@ class TestBlackbox(TestCaseWithPipes):
 
     def test_add_pipe_no_switch_stores_uncommitted(self):
         self.do_add(no_switch=True)
-        self.failUnlessExists('checkout/file1')
-        self.failIfExists('checkout/file2')
+        self.assertPathExists('checkout/file1')
+        self.assertPathDoesNotExist('checkout/file2')
 
     def test_add_pipe_keeps_uncommitted(self):
         self.do_add(no_switch=False)
-        self.failUnlessExists('checkout/file1')
-        self.failUnlessExists('checkout/file2')
+        self.assertPathExists('checkout/file1')
+        self.assertPathExists('checkout/file2')
 
     def test_add_pipe_accepts_branch(self):
         self.make_branch_and_checkout('first')
@@ -196,13 +196,13 @@ class TestBlackbox(TestCaseWithPipes):
         tree = self.make_branch_and_checkout('first')
         PipeStorage(tree.branch).insert_pipe('second')
         self.run_bzr('remove-pipe second', working_dir='checkout')
-        self.failUnlessExists('second')
+        self.assertPathExists('second')
 
     def test_remove_pipe_branch(self):
         tree = self.make_branch_and_checkout('first')
         PipeStorage(tree.branch).insert_pipe('second')
         self.run_bzr('remove-pipe second --branch', working_dir='checkout')
-        self.failIfExists('second')
+        self.assertPathDoesNotExist('second')
 
     def test_rename_pipe(self):
         tree = self.make_branch_and_checkout('first')
@@ -215,9 +215,9 @@ class TestBlackbox(TestCaseWithPipes):
         self.build_tree(['checkout/file3'])
         workingtree.WorkingTree.open('checkout').add('file3')
         out, err = self.run_bzr('switch-pipe next -d checkout')
-        self.failUnlessExists('checkout/file1')
-        self.failUnlessExists('checkout/file2')
-        self.failIfExists('checkout/file3')
+        self.assertPathExists('checkout/file1')
+        self.assertPathExists('checkout/file2')
+        self.assertPathDoesNotExist('checkout/file3')
         self.assertEqual('Uncommitted changes stored in pipe "first".\n'
                          'Switched from "first" to "next".\n', err)
 
@@ -228,7 +228,7 @@ class TestBlackbox(TestCaseWithPipes):
         foo.add('file')
         out, err = self.run_bzr('switch-pipe bar', working_dir='foo',
                                 retcode=3)
-        self.failUnlessExists('foo/file')
+        self.assertPathExists('foo/file')
         self.assertContainsRe(err, 'Directory is not a lightweight checkout.')
 
     def test_switch_pipe_accepts_aliases(self):
@@ -288,7 +288,7 @@ class TestBlackbox(TestCaseWithPipes):
         two = PipeStorage(one).insert_pipe('two')
         two.create_checkout('checkout', lightweight=True)
         self.run_bzr('pump -d checkout --from from')
-        self.failUnlessExists('checkout/from-file')
+        self.assertPathExists('checkout/from-file')
 
     def test_pump_from_pipe(self):
         checkout = self.make_branch_and_checkout('one')
@@ -298,11 +298,11 @@ class TestBlackbox(TestCaseWithPipes):
         self.build_tree(['checkout/one-file'])
         checkout.add('one-file')
         checkout.commit('added one-file.')
-        self.failUnlessExists('checkout/one-file')
+        self.assertPathExists('checkout/one-file')
         manager.switch_to_pipe(two)
         self.run_bzr('pump -d checkout --from one')
         self.run_bzr('update checkout')
-        self.failUnlessExists('checkout/one-file')
+        self.assertPathExists('checkout/one-file')
 
     def test_pump_from_submit(self):
         submit = self.make_branch_and_tree('submit')
@@ -315,7 +315,7 @@ class TestBlackbox(TestCaseWithPipes):
         two = PipeStorage(one).insert_pipe('two')
         two.create_checkout('checkout', lightweight=True)
         self.run_bzr('pump -d checkout --from-submit')
-        self.failUnlessExists('checkout/submit-file')
+        self.assertPathExists('checkout/submit-file')
 
     def get_merge_text(self, foo, *options):
         out, err = self.run_bzr(['pump', '-d', 'checkout'] + list(options))
@@ -363,7 +363,7 @@ class TestBlackbox(TestCaseWithPipes):
         bar = PipeManager(PipeStorage(foo).insert_pipe('bar'), checkout)
         bar.store_uncommitted()
         self.run_bzr('merge -d checkout --uncommitted bar')
-        self.failUnlessExists('checkout/file')
+        self.assertPathExists('checkout/file')
         self.assertTrue(bar.has_stored_changes())
 
     def test_merge_uncommitted_from_pipe_alias(self):
@@ -375,7 +375,7 @@ class TestBlackbox(TestCaseWithPipes):
         bar = PipeManager(PipeStorage(foo).insert_pipe('bar'), checkout)
         bar.store_uncommitted()
         self.run_bzr('merge --uncommitted :next', working_dir='checkout')
-        self.failUnlessExists('checkout/file')
+        self.assertPathExists('checkout/file')
         self.assertTrue(bar.has_stored_changes())
 
     def test_merge_uncommitted_no_location_uses_submit_branch(self):
@@ -386,15 +386,15 @@ class TestBlackbox(TestCaseWithPipes):
         bar.add('file')
         foo.branch.set_submit_branch(bar.branch.base)
         self.run_bzr('merge --uncommitted', working_dir='checkout')
-        self.failUnlessExists('checkout/file')
+        self.assertPathExists('checkout/file')
 
     def test_sync_pipeline(self):
         self.build_tree(['local/', 'remote/'])
         foo = PipeStorage(self.make_branch('local/foo'))
         foo.insert_pipe('bar')
         self.run_bzr('sync-pipeline ../../remote/foo', working_dir='local/foo')
-        self.failUnlessExists('remote/foo')
-        self.failUnlessExists('remote/bar')
+        self.assertPathExists('remote/foo')
+        self.assertPathExists('remote/bar')
 
     def test_sync_pipeline_default(self):
         self.build_tree(['local/', 'remote/'])
@@ -402,8 +402,8 @@ class TestBlackbox(TestCaseWithPipes):
         foo.insert_pipe('bar')
         foo.branch.set_push_location(osutils.abspath('remote/foo'))
         self.run_bzr('sync-pipeline', working_dir='local/foo')
-        self.failUnlessExists('remote/foo')
-        self.failUnlessExists('remote/bar')
+        self.assertPathExists('remote/foo')
+        self.assertPathExists('remote/bar')
 
     def test_sync_pipeline_errors_if_default_none(self):
         self.build_tree(['local/', 'remote/'])
@@ -421,8 +421,8 @@ class TestBlackbox(TestCaseWithPipes):
         foo.branch.set_push_location(osutils.abspath('remote/foo'))
         bar.set_push_location(osutils.abspath('nowhere/bar'))
         self.run_bzr('sync-pipeline', working_dir='local/bar')
-        self.failUnlessExists('remote/foo')
-        self.failUnlessExists('remote/bar')
+        self.assertPathExists('remote/foo')
+        self.assertPathExists('remote/bar')
 
     def test_sync_pipeline_falls_back_to_other_pipes(self):
         self.build_tree(['local/', 'remote/'])
@@ -430,8 +430,8 @@ class TestBlackbox(TestCaseWithPipes):
         bar = foo.insert_pipe('bar')
         bar.set_push_location(osutils.abspath('remote/bar'))
         self.run_bzr('sync-pipeline', working_dir='local/foo')
-        self.failUnlessExists('remote/foo')
-        self.failUnlessExists('remote/bar')
+        self.assertPathExists('remote/foo')
+        self.assertPathExists('remote/bar')
 
     def test_sync_pipeline_previous_pipe_added_with_push_loc(self):
         self.build_tree(['local/', 'remote/'])
@@ -444,7 +444,7 @@ class TestBlackbox(TestCaseWithPipes):
     def test_reconfigure_pipeline(self):
         self.make_branch_and_tree('pipeline')
         self.run_bzr('reconfigure-pipeline', working_dir='pipeline')
-        branch.Branch.open('pipeline/.bzr/pipes/pipeline')
+        branch.Branch.open('pipeline/.bzr/branches/pipeline')
 
     def assertFileContainsRe(self, regex, path):
         try:
