@@ -224,7 +224,7 @@ class TestPipeManager(TestCaseWithPipes):
 
     def test_store_uncommitted(self):
         self.store_uncommitted()
-        self.failIfExists('tree/file')
+        self.assertPathDoesNotExist('tree/file')
 
     def test_store_uncommitted_no_change(self):
         tree = self.make_branch_and_tree('tree')
@@ -256,7 +256,7 @@ class TestPipeManager(TestCaseWithPipes):
     def test_restore_uncommitted(self):
         tree, manager = self.store_uncommitted()
         manager.restore_uncommitted()
-        self.failUnlessExists('tree/file')
+        self.assertPathExists('tree/file')
         self.assertFalse(None, manager.has_stored_changes())
 
     def test_restore_uncommitted_none(self):
@@ -289,11 +289,11 @@ class TestPipeManager(TestCaseWithPipes):
         self.build_tree(['checkout/file'])
         tree.add('file')
         manager.switch_to_pipe(second)
-        self.failIfExists('checkout/file')
+        self.assertPathDoesNotExist('checkout/file')
         tree = workingtree.WorkingTree.open('checkout')
         first = branch.Branch.open('first')
         manager = PipeManager(tree.branch, tree).switch_to_pipe(first)
-        self.failUnlessExists('checkout/file')
+        self.assertPathExists('checkout/file')
         self.assertFalse(manager.storage.has_stored_changes())
         tree = workingtree.WorkingTree.open('checkout')
         self.assertEqual(manager.storage.branch.base, tree.branch.base)
@@ -315,7 +315,7 @@ class TestPipeManager(TestCaseWithPipes):
         tree = workingtree.WorkingTree.open('checkout')
         self.assertEqual(manager.storage.branch.base, tree.branch.base)
         self.assertEqual('rev3-id', tree.last_revision())
-        self.failUnlessExists('checkout/file2')
+        self.assertPathExists('checkout/file2')
 
     def test_switch_to_pipe_local_conflicts(self):
         tree, manager, second = self.make_checkout_first_second()
@@ -423,7 +423,7 @@ class TestPipeManager(TestCaseWithPipes):
         manager.pipeline_merge(from_branch=submit.branch)
         basis = checkout.branch.basis_tree()
         self.assertIsNot(None, basis.path2id('submit-file'))
-        self.failUnlessExists('checkout/submit-file')
+        self.assertPathExists('checkout/submit-file')
 
     def test_pipeline_merge_from_branch_no_change(self):
         submit = self.make_branch_and_tree('submit')
@@ -648,7 +648,24 @@ class TestPipeManager(TestCaseWithPipes):
         remote_tree.commit('added file')
         manager = PipeManager(tree.branch, tree)
         manager.sync_pipeline('remote/first')
-        self.failUnlessExists('checkout/file')
+        self.assertPathExists('checkout/file')
+
+    def test_sync_pipeline_uses_correct_revisions(self):
+        os.mkdir('local')
+        checkout = self.make_branch_and_checkout('local/first')
+        first = checkout.branch
+        first_rev = checkout.commit('first')
+        first_manager = PipeManager.from_checkout(checkout)
+        second = first_manager.storage.insert_pipe('second')
+        first_manager.switch_to_pipe(second)
+        checkout = reload_tree(checkout)
+        second_rev = checkout.commit('second')
+        os.mkdir('remote')
+        PipeManager.from_checkout(checkout).sync_pipeline('remote/first')
+        self.assertEqual(first_rev,
+                branch.Branch.open('remote/first').last_revision())
+        self.assertEqual(second_rev,
+                branch.Branch.open('remote/second').last_revision())
 
     def test_merge_nick_order(self):
         """All nicks must appear once in the result.
@@ -717,6 +734,32 @@ class TestPipeManager(TestCaseWithPipes):
         manager = PipeManager(child.branch, child)
         self.assertEqual('parent-1', manager.get_prev_revision_id())
 
+    def test_remove_pipe(self):
+        checkout = self.make_branch_and_checkout('doomed')
+        manager = PipeManager.from_checkout(checkout)
+        target = manager.storage.insert_pipe('target')
+        manager.remove_pipe(target, False)
+        manager = PipeManager.from_checkout(reload_tree(checkout))
+        self.assertEqual(target.base, manager.checkout.branch.base)
+
+    def test_remove_pipe_unshelves(self):
+        checkout = self.make_branch_and_checkout('wip')
+        checkout.commit('empty')
+        self.build_tree(['checkout/new'])
+        checkout.add('new')
+        manager = PipeManager.from_checkout(checkout)
+        doomed = manager.storage.insert_pipe('doomed')
+        manager.switch_to_pipe(doomed)
+        self.assertPathDoesNotExist('checkout/new')
+        branch = checkout.branch
+        manager = PipeManager.from_checkout(reload_tree(checkout))
+        manager.remove_pipe(branch, False)
+        self.assertPathExists('checkout/new')
+
+
+def reload_tree(tree):
+    return workingtree.WorkingTree.open(tree.bzrdir.root_transport.base)
+
 
 class TestGetDiff(tests.TestCaseWithMemoryTransport):
 
@@ -827,10 +870,11 @@ class TestTreeToPipeline(TestCaseWithPipes):
         tree.branch.nick = 'bar'
         tree.commit('rev1', rev_id='rev1-id')
         tree_to_pipeline(tree)
-        b = branch.Branch.open('foo/.bzr/pipes/bar')
+        b = branch.Branch.open('foo/.bzr/branches/bar')
         self.assertEqual('rev1-id', b.last_revision())
         self.assertRaises(errors.NoWorkingTree,
-                          workingtree.WorkingTree.open, 'foo/.bzr/pipes/bar')
+                          workingtree.WorkingTree.open,
+                          'foo/.bzr/branches/bar')
         self.assertTrue(b.repository.is_shared())
         self.assertEqual(b.base, branch.Branch.open('foo').base)
         self.assertFalse(tree.is_ignored('pipes'))
